@@ -1,12 +1,8 @@
 #!/usr/bin/env python3
-"""Django's command-line utility for administrative tasks."""
-import os
-import sys
-
-
+import os,sys
+from fil3s import *
 def main():
-    """Run administrative tasks."""
-    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'website.settings')
+    os.environ.setdefault('DJANGO_SETTINGS_MODULE', '__defaults__.django.settings')
     try:
         from django.core.management import execute_from_command_line
     except ImportError as exc:
@@ -16,7 +12,6 @@ def main():
             "forget to activate a virtual environment?"
         ) from exc
     execute_from_command_line(sys.argv)
-
-
 if __name__ == '__main__':
-    main()
+    os.chdir(gfp.base(__file__, back=2))
+    main()
\ No newline at end of file
